@@ -106,6 +106,7 @@ and cpio_arch magic orig_path path =
     if String.find magic "gzip" >= 0 then "zcat"
     else if String.find magic "bzip2" >= 0 then "bzcat"
     else if String.find magic "XZ compressed" >= 0 then "xzcat"
+    else if String.find magic "Zstandard compressed" >= 0 then "zstdcat"
     else "cat" in
 
   let tmpdir = Mkdtemp.temp_dir "filearch" in
@@ -127,7 +128,7 @@ and cpio_arch magic orig_path path =
         | bin :: bins ->
            let bin_path = tmpdir // bin in
            if is_regular_file bin_path then (
-             let out = command "file" ["-zb"; bin_path] in
+             let out = command "file" ["-zSb"; bin_path] in
              file_architecture_of_magic out orig_path bin_path
            )
            else
