@@ -49,22 +49,10 @@
 
 #include "c-ctype.h"
 #include "ignore-value.h"
-#include "sockets.h"
 
 #include "daemon.h"
 
 static void makeraw (const char *channel, int fd);
-static int print_shell_quote (FILE *stream, const struct printf_info *info, const void *const *args);
-static int print_sysroot_shell_quote (FILE *stream, const struct printf_info *info, const void *const *args);
-#ifdef HAVE_REGISTER_PRINTF_SPECIFIER
-static int print_arginfo (const struct printf_info *info, size_t n, int *argtypes, int *size);
-#else
-#ifdef HAVE_REGISTER_PRINTF_FUNCTION
-static int print_arginfo (const struct printf_info *info, size_t n, int *argtypes);
-#else
-#error "HAVE_REGISTER_PRINTF_{SPECIFIER|FUNCTION} not defined"
-#endif
-#endif
 
 #ifdef WIN32
 static int
@@ -116,29 +104,6 @@ main (int argc, char *argv[])
   if (winsock_init () == -1)
     error (EXIT_FAILURE, 0, "winsock initialization failed");
 
-#ifdef HAVE_REGISTER_PRINTF_SPECIFIER
-  /* http://udrepper.livejournal.com/20948.html */
-  register_printf_specifier ('Q', print_shell_quote, print_arginfo);
-  register_printf_specifier ('R', print_sysroot_shell_quote, print_arginfo);
-#else
-#ifdef HAVE_REGISTER_PRINTF_FUNCTION
-  register_printf_function ('Q', print_shell_quote, print_arginfo);
-  register_printf_function ('R', print_sysroot_shell_quote, print_arginfo);
-#else
-#error "HAVE_REGISTER_PRINTF_{SPECIFIER|FUNCTION} not defined"
-#endif
-#endif
-
-  /* XXX The appliance /init script sets LD_PRELOAD=../libSegFault.so.
-   * However if we CHROOT_IN to the sysroot that file might not exist,
-   * resulting in all commands failing.  What we'd really like to do
-   * is to have LD_PRELOAD only set while outside the chroot.  I
-   * suspect the proper way to solve this is to remove the
-   * CHROOT_IN/_OUT hack and replace it properly (fork), but that is
-   * for another day.
-   */
-  unsetenv ("LD_PRELOAD");
-
   struct stat statbuf;
   if (stat ("/", &statbuf) == 0)
     root_device = statbuf.st_dev;
@@ -348,62 +313,30 @@ makeraw (const char *channel, int fd)
 }
 
 /**
- * printf helper function so we can use C<%Q> ("quoted") and C<%R> to
- * print shell-quoted strings.  See L<guestfs-hacking(1)> for more
- * details.
+ * Write C<str> to the file C<fp>, ensuring it is shell quoted.
  */
-static int
-print_shell_quote (FILE *stream,
-                   const struct printf_info *info ATTRIBUTE_UNUSED,
-                   const void *const *args)
+void
+shell_quote (const char *str, FILE *fp)
 {
 #define SAFE(c) (c_isalnum((c)) ||					\
                  (c) == '/' || (c) == '-' || (c) == '_' || (c) == '.')
-  int i, len;
-  const char *str = *((const char **) (args[0]));
+  size_t i;
 
-  for (i = len = 0; str[i]; ++i) {
+  for (i = 0; str[i]; ++i) {
     if (!SAFE (str[i])) {
-      putc ('\\', stream);
-      len ++;
+      putc ('\\', fp);
     }
-    putc (str[i], stream);
-    len ++;
+    putc (str[i], fp);
   }
-
-  return len;
 }
 
-static int
-print_sysroot_shell_quote (FILE *stream,
-                           const struct printf_info *info,
-                           const void *const *args)
+/**
+ * Write C<sysroot> + C<path> to the file C<fp>, ensuring it is shell
+ * quoted.  The path must be an absolute path.
+ */
+void
+sysroot_shell_quote (const char *path, FILE *fp)
 {
-  fputs (sysroot, stream);
-  return sysroot_len + print_shell_quote (stream, info, args);
+  fputs (sysroot, fp);
+  shell_quote (path, fp);
 }
-
-#ifdef HAVE_REGISTER_PRINTF_SPECIFIER
-static int
-print_arginfo (const struct printf_info *info ATTRIBUTE_UNUSED,
-               size_t n, int *argtypes, int *size)
-{
-  if (n > 0) {
-    argtypes[0] = PA_STRING;
-    size[0] = sizeof (const char *);
-  }
-  return 1;
-}
-#else
-#ifdef HAVE_REGISTER_PRINTF_FUNCTION
-static int
-print_arginfo (const struct printf_info *info, size_t n, int *argtypes)
-{
-  if (n > 0)
-    argtypes[0] = PA_STRING;
-  return 1;
-}
-#else
-#error "HAVE_REGISTER_PRINTF_{SPECIFIER|FUNCTION} not defined"
-#endif
-#endif
