@@ -259,6 +259,7 @@ and check_package_format { distro } =
   | None -> None
   | Some DISTRO_ALTLINUX
   | Some DISTRO_CENTOS
+  | Some DISTRO_ROCKY
   | Some DISTRO_FEDORA
   | Some DISTRO_MAGEIA
   | Some DISTRO_MANDRIVA
@@ -275,6 +276,7 @@ and check_package_format { distro } =
      Some PACKAGE_FORMAT_RPM
   | Some DISTRO_DEBIAN
   | Some DISTRO_KALI_LINUX
+  | Some DISTRO_KYLIN (* supposedly another Ubuntu derivative *)
   | Some DISTRO_LINUX_MINT
   | Some DISTRO_UBUNTU ->
      Some PACKAGE_FORMAT_DEB
@@ -328,6 +330,7 @@ and check_package_management { distro; version } =
      Some PACKAGE_MANAGEMENT_DNF
 
   | Some DISTRO_CENTOS
+  | Some DISTRO_ROCKY
   | Some DISTRO_ORACLE_LINUX
   | Some DISTRO_REDHAT_BASED
   | Some DISTRO_RHEL
@@ -345,6 +348,7 @@ and check_package_management { distro; version } =
   | Some DISTRO_ALTLINUX
   | Some DISTRO_DEBIAN
   | Some DISTRO_KALI_LINUX
+  | Some DISTRO_KYLIN (* supposedly another Ubuntu derivative *)
   | Some DISTRO_LINUX_MINT
   | Some DISTRO_UBUNTU ->
      Some PACKAGE_MANAGEMENT_APT
