@@ -32,6 +32,8 @@ let re_rhel_no_minor = PCRE.compile "Red Hat.*release (\\d+)"
 let re_centos_old = PCRE.compile "CentOS.*release (\\d+).*Update (\\d+)"
 let re_centos = PCRE.compile "CentOS.*release (\\d+)\\.(\\d+)"
 let re_centos_no_minor = PCRE.compile "CentOS.*release (\\d+)"
+let re_rocky = PCRE.compile "Rocky Linux.*release (\\d+)\\.(\\d+)"
+let re_rocky_no_minor = PCRE.compile "Rocky Linux.*release (\\d+)"
 let re_scientific_linux_old =
   PCRE.compile "Scientific Linux.*release (\\d+).*Update (\\d+)"
 let re_scientific_linux =
@@ -106,7 +108,7 @@ let rec parse_os_release release_file data =
         * we detect that situation then bail out and use the release
         * files instead.
         *)
-       | { distro = Some (DISTRO_DEBIAN|DISTRO_CENTOS);
+       | { distro = Some (DISTRO_DEBIAN|DISTRO_CENTOS|DISTRO_ROCKY);
            version = Some (_, 0) } ->
           false
 
@@ -146,13 +148,16 @@ and distro_of_os_release_id = function
   | "frugalware" -> Some DISTRO_FRUGALWARE
   | "gentoo" -> Some DISTRO_GENTOO
   | "kali" -> Some DISTRO_KALI_LINUX
+  | "kylin" -> Some DISTRO_KYLIN
   | "mageia" -> Some DISTRO_MAGEIA
   | "neokylin" -> Some DISTRO_NEOKYLIN
   | "openmandriva" -> Some DISTRO_OPENMANDRIVA
   | "opensuse" -> Some DISTRO_OPENSUSE
   | s when String.is_prefix s "opensuse-" -> Some DISTRO_OPENSUSE
+  | "pardus" -> Some DISTRO_PARDUS
   | "pld" -> Some DISTRO_PLD_LINUX
   | "rhel" -> Some DISTRO_RHEL
+  | "rocky" -> Some DISTRO_ROCKY
   | "sles" | "sled" -> Some DISTRO_SLES
   | "ubuntu" -> Some DISTRO_UBUNTU
   | "void" -> Some DISTRO_VOID_LINUX
@@ -403,6 +408,10 @@ let linux_root_tests : tests = [
                                        DISTRO_CENTOS;
   "/etc/centos-release", parse_generic ~rex:re_centos_no_minor
                                        DISTRO_CENTOS;
+  "/etc/rocky-release", parse_generic ~rex:re_rocky
+                                       DISTRO_ROCKY;
+  "/etc/rocky-release", parse_generic ~rex:re_rocky_no_minor
+                                       DISTRO_ROCKY;
   "/etc/altlinux-release", parse_generic DISTRO_ALTLINUX;
   "/etc/redhat-release", parse_generic ~rex:re_fedora
                                        DISTRO_FEDORA;
@@ -418,6 +427,10 @@ let linux_root_tests : tests = [
                                        DISTRO_CENTOS;
   "/etc/redhat-release", parse_generic ~rex:re_centos_no_minor
                                        DISTRO_CENTOS;
+  "/etc/redhat-release", parse_generic ~rex:re_rocky
+                                       DISTRO_ROCKY;
+  "/etc/redhat-release", parse_generic ~rex:re_rocky_no_minor
+                                       DISTRO_ROCKY;
   "/etc/redhat-release", parse_generic ~rex:re_scientific_linux_old
                                        DISTRO_SCIENTIFIC_LINUX;
   "/etc/redhat-release", parse_generic ~rex:re_scientific_linux
@@ -538,15 +551,28 @@ and check_hostname_linux () =
      else
        None
 
-(* Parse the hostname where it is stored directly in a file. *)
+(* Parse the hostname where it is stored directly in a file.
+ *
+ * For /etc/hostname:
+ * "The file should contain a single newline-terminated hostname
+ * string. Comments (lines starting with a "#") are ignored."
+ * [https://www.freedesktop.org/software/systemd/man/hostname.html]
+ *
+ * For other hostname files the exact format is not clear, but
+ * hostnames cannot begin with "#" and cannot be empty, so ignoring
+ * those lines seems safe.
+ *)
 and check_hostname_from_file filename =
   let chroot =
     let name = sprintf "check_hostname_from_file: %s" filename in
     Chroot.create ~name () in
 
   let hostname = Chroot.f chroot read_small_file filename in
-  match hostname with
-  | None | Some [] | Some [""] -> None
+
+  let keep_line line = line <> "" && not (String.is_prefix line "#") in
+  let lines = Option.map (List.filter keep_line) hostname in
+  match lines with
+  | None | Some [] -> None
   | Some (hostname :: _) -> Some hostname
 
 (* Parse the hostname from /etc/sysconfig/network.  This must be
