@@ -1185,6 +1185,13 @@ construct_libvirt_xml_cpu (guestfs_h *g,
       else if (STREQ (cpu_model, "max")) {
         /* https://bugzilla.redhat.com/show_bug.cgi?id=1935572#c11 */
         attribute ("mode", "maximum");
+#if defined(__x86_64__)
+        /* Temporary workaround for RHBZ#2082806 */
+        start_element ("feature") {
+          attribute ("policy", "disable");
+          attribute ("name", "la57");
+        } end_element ();
+#endif
       }
       else
         single_element ("model", cpu_model);
@@ -2298,137 +2305,12 @@ max_disks_libvirt (guestfs_h *g, void *datav)
   return 255;
 }
 
-static xmlChar *construct_libvirt_xml_hot_add_disk (guestfs_h *g, const struct backend_libvirt_data *data, struct drive *drv, size_t drv_index);
-
-/* Hot-add a drive.  Note the appliance is up when this is called. */
-static int
-hot_add_drive_libvirt (guestfs_h *g, void *datav,
-                       struct drive *drv, size_t drv_index)
-{
-  struct backend_libvirt_data *data = datav;
-  virConnectPtr conn = data->conn;
-  virDomainPtr dom = data->dom;
-  CLEANUP_FREE xmlChar *xml = NULL;
-
-  if (!conn || !dom) {
-    /* This is essentially an internal error if it happens. */
-    error (g, "%s: conn == NULL or dom == NULL", __func__);
-    return -1;
-  }
-
-  /* If the drive has an associated secret, store it in libvirt. */
-  if (add_secret (g, conn, data, drv) == -1)
-    return -1;
-
-  /* Create the XML for the new disk. */
-  xml = construct_libvirt_xml_hot_add_disk (g, data, drv, drv_index);
-  if (xml == NULL)
-    return -1;
-
-  /* Attach it. */
-  if (virDomainAttachDeviceFlags (dom, (char *) xml,
-                                  VIR_DOMAIN_DEVICE_MODIFY_LIVE) == -1) {
-    libvirt_error (g, _("could not attach disk to libvirt domain"));
-    return -1;
-  }
-
-  return 0;
-}
-
-/* Hot-remove a drive.  Note the appliance is up when this is called. */
-static int
-hot_remove_drive_libvirt (guestfs_h *g, void *datav,
-                          struct drive *drv, size_t drv_index)
-{
-  struct backend_libvirt_data *data = datav;
-  virConnectPtr conn = data->conn;
-  virDomainPtr dom = data->dom;
-  CLEANUP_FREE xmlChar *xml = NULL;
-
-  if (!conn || !dom) {
-    /* This is essentially an internal error if it happens. */
-    error (g, "%s: conn == NULL or dom == NULL", __func__);
-    return -1;
-  }
-
-  /* Re-create the XML for the disk. */
-  xml = construct_libvirt_xml_hot_add_disk (g, data, drv, drv_index);
-  if (xml == NULL)
-    return -1;
-
-  /* Detach it. */
-  if (virDomainDetachDeviceFlags (dom, (char *) xml,
-                                  VIR_DOMAIN_DEVICE_MODIFY_LIVE) == -1) {
-    libvirt_error (g, _("could not detach disk from libvirt domain"));
-    return -1;
-  }
-
-  return 0;
-}
-
-static xmlChar *
-construct_libvirt_xml_hot_add_disk (guestfs_h *g,
-                                    const struct backend_libvirt_data *data,
-                                    struct drive *drv,
-                                    size_t drv_index)
-{
-  xmlChar *ret = NULL;
-  CLEANUP_XMLBUFFERFREE xmlBufferPtr xb = NULL;
-  xmlOutputBufferPtr ob;
-  CLEANUP_XMLFREETEXTWRITER xmlTextWriterPtr xo = NULL;
-
-  xb = xmlBufferCreate ();
-  if (xb == NULL) {
-    perrorf (g, "xmlBufferCreate");
-    return NULL;
-  }
-  ob = xmlOutputBufferCreateBuffer (xb, NULL);
-  if (ob == NULL) {
-    perrorf (g, "xmlOutputBufferCreateBuffer");
-    return NULL;
-  }
-  xo = xmlNewTextWriter (ob);
-  if (xo == NULL) {
-    perrorf (g, "xmlNewTextWriter");
-    return NULL;
-  }
-
-  if (xmlTextWriterSetIndent (xo, 1) == -1 ||
-      xmlTextWriterSetIndentString (xo, BAD_CAST "  ") == -1) {
-    perrorf (g, "could not set XML indent");
-    return NULL;
-  }
-  if (xmlTextWriterStartDocument (xo, NULL, NULL, NULL) == -1) {
-    perrorf (g, "xmlTextWriterStartDocument");
-    return NULL;
-  }
-
-  if (construct_libvirt_xml_disk (g, data, xo, drv, drv_index) == -1)
-    return NULL;
-
-  if (xmlTextWriterEndDocument (xo) == -1) {
-    perrorf (g, "xmlTextWriterEndDocument");
-    return NULL;
-  }
-  ret = xmlBufferDetach (xb); /* caller frees ret */
-  if (ret == NULL) {
-    perrorf (g, "xmlBufferDetach");
-    return NULL;
-  }
-
-  debug (g, "hot-add disk XML:\n%s", ret);
-
-  return ret;
-}
-
 static struct backend_ops backend_libvirt_ops = {
   .data_size = sizeof (struct backend_libvirt_data),
   .create_cow_overlay = create_cow_overlay_libvirt,
   .launch = launch_libvirt,
   .shutdown = shutdown_libvirt,
   .max_disks = max_disks_libvirt,
-  .hot_add_drive = hot_add_drive_libvirt,
-  .hot_remove_drive = hot_remove_drive_libvirt,
 };
 
 void
