@@ -1,5 +1,5 @@
 /* libguestfs
- * Copyright (C) 2009-2019 Red Hat Inc.
+ * Copyright (C) 2009-2020 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -433,7 +433,7 @@ send_file_cancellation (guestfs_h *g)
 static int
 send_file_complete (guestfs_h *g)
 {
-  char buf[1];
+  char buf[1] = { '\0' };
   return send_file_chunk (g, 0, buf, 0);
 }
 
