@@ -21,4 +21,6 @@ set -e
 $TEST_FUNCTIONS
 skip_if_skipped
 
-$top_srcdir/podcheck.pl virt-rescue.pod virt-rescue
+$top_srcdir/podcheck.pl "$srcdir/virt-rescue.pod" virt-rescue \
+                        --path $top_srcdir/common/options \
+                        --ignore=--suggest
