@@ -20,46 +20,48 @@ set -e
 
 $TEST_FUNCTIONS
 skip_if_skipped
-skip_if_backend uml
 skip_unless_feature_available btrfs
 
 canonical="sed s,/dev/vd,/dev/sd,g"
 
-rm -f root.tmp test.qcow2 test.output
+root=mountable-inspect.tmp
+output=mountable-inspect.output
+overlay=mountable-inspect.qcow2
+rm -f $root $overlay $output
 
 # Start with the regular (good) fedora image, modify /etc/fstab
 # and then inspect it.
 guestfish -- \
-  disk-create test.qcow2 qcow2 -1 \
+  disk-create $overlay qcow2 -1 \
     backingfile:../test-data/phony-guests/fedora-btrfs.img backingformat:raw
 
 # Test that basic inspection works and the expected filesystems are
 # found
-guestfish --format=qcow2 -a test.qcow2 -i <<'EOF' | sort | $canonical > test.output
-  inspect-get-roots | head -1 > root.tmp
-  <! echo inspect-get-mountpoints "`cat root.tmp`"
+guestfish --format=qcow2 -a $overlay -i <<EOF | sort | $canonical > $output
+  inspect-get-roots | head -1 > $root
+  <! echo inspect-get-mountpoints \"\`cat $root\`\"
 EOF
 
-if [ "$(cat test.output)" != "/: btrfsvol:/dev/sda2/root
+if [ "$(cat $output)" != "/: btrfsvol:/dev/sda2/root
 /boot: /dev/sda1
 /home: btrfsvol:/dev/sda2/home" ]; then
     echo "$0: error #1: unexpected output from inspect-get-mountpoints"
-    cat test.output
+    cat $output
     exit 1
 fi
 
 # Additional sanity check: did we get the release name right?
-guestfish --format=qcow2 -a test.qcow2 -i <<'EOF' > test.output
-  inspect-get-roots | head -1 > root.tmp
-  <! echo inspect-get-product-name "`cat root.tmp`"
+guestfish --format=qcow2 -a $overlay -i <<EOF > $output
+  inspect-get-roots | head -1 > $root
+  <! echo inspect-get-product-name \"\`cat $root\`\"
 EOF
 
-if [ "$(cat test.output)" != "Fedora release 14 (Phony)" ]; then
+if [ "$(cat $output)" != "Fedora release 14 (Phony)" ]; then
     echo "$0: error #2: unexpected output from inspect-get-product-name"
-    cat test.output
+    cat $output
     exit 1
 fi
 
-rm root.tmp
-rm test.qcow2
-rm test.output
+rm $root
+rm $overlay
+rm $output
